from dataclasses import dataclass
from typing import Optional

from .validation_result import ValidationResult


@dataclass
class StateValidationResult:
    access_token: str = ""
    id_token: str = ""
    auth_response_is_valid: bool = False
    state: ValidationResult = ValidationResult.NotSet
    decoded_id_token: Optional[dict] = None



from enum import Enum


class ValidationResult(Enum):
    NotSet = ("NotSet",)
    StatesDoNotMatch = ("StatesDoNotMatch",)
    SignatureFailed = ("SignatureFailed",)
    IncorrectNonce = ("IncorrectNonce",)
    RequiredPropertyMissing = ("RequiredPropertyMissing",)
    MaxOffsetExpired = ("MaxOffsetExpired",)
    IssDoesNotMatchIssuer = ("IssDoesNotMatchIssuer",)
    NoAuthWellKnownEndPoints = ("NoAuthWellKnownEndPoints",)
    IncorrectAud = ("IncorrectAud",)
    IncorrectIdTokenClaimsAfterRefresh = (
        "IncorrectIdTokenClaimsAfterRefresh",
    )
    IncorrectAzp = ("IncorrectAzp",)
    TokenExpired = ("TokenExpired",)
    IncorrectAtHash = ("IncorrectAtHash",)
    Ok = ("Ok",)
    LoginRequired = ("LoginRequired",)
    SecureTokenServerError = ("SecureTokenServerError",)
